@@ -11,6 +11,7 @@ from qtpy.QtCore import Slot, Property, Qt, QSize, QPoint
 from .base import PyDMPrimitiveWidget
 from ..utilities import IconFont, find_file, is_pydm_app
 from ..utilities.macro import parse_macro_string
+from ..utilities.stylesheet import merge_widget_stylesheet
 from ..display import (load_file, ScreenTarget)
 
 
@@ -426,6 +427,11 @@ class PyDMRelatedDisplayButton(QPushButton, PyDMPrimitiveWidget, new_properties=
             PyDMRelatedDisplayButton.EXISTING_WINDOW or 0 will open the
             file on the same window. PyDMRelatedDisplayButton.NEW_WINDOW
             or 1 will result on a new process.
+
+        Returns
+        -------
+        display : Display
+            The widget that was opened. Useful for testing and debug.
         """
         if not self.validate_password():
             return None
@@ -457,11 +463,15 @@ class PyDMRelatedDisplayButton(QPushButton, PyDMPrimitiveWidget, new_properties=
 
         if is_pydm_app():
             if target == self.NEW_WINDOW:
-                load_file(fname, macros=macros, target=screen_target)
+                return load_file(fname, macros=macros, target=screen_target)
             else:
-                self.window().open(fname, macros=macros)
+                return self.window().open(fname, macros=macros)
         else:
-            w = load_file(fname, macros=macros, target=ScreenTarget.DIALOG)
+            display = load_file(fname, macros=macros, target=ScreenTarget.DIALOG)
+            # Not a pydm app: need to give our new display proper pydm styling
+            # Usually done in PyDMApplication
+            merge_widget_stylesheet(widget=display)
+            return display
 
     def context_menu(self):
         try:
